/*

Copyright (c) 2003 Chris Lundie
http://lundie.ca/

This file is part of IP2Clip.

IP2Clip is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

IP2Clip is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with IP2Clip; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#define WIN32_LEAN_AND_MEAN
#include <windows.h>
#include <iphlpapi.h>
#include <sstream>

int WINAPI
WinMain(
	HINSTANCE hInstance,
	HINSTANCE hPrevInstance,
	LPSTR lpCmdLine,
	int nCmdShow)
{
	ULONG dwSize = 0;
	if (ERROR_INSUFFICIENT_BUFFER != GetIpAddrTable(NULL, &dwSize, FALSE))
		return 1;

	MIB_IPADDRTABLE* pAddrTable = static_cast<MIB_IPADDRTABLE*>(GlobalAlloc(GMEM_FIXED, dwSize));
	if (!pAddrTable)
		return 1;

	if (NO_ERROR != GetIpAddrTable(pAddrTable, &dwSize, FALSE))
	{
		GlobalFree(pAddrTable);
		return 1;
	}

	for (DWORD i=0; i<pAddrTable->dwNumEntries; ++i)
	{
		if (pAddrTable->table[i].dwAddr == 0)
			continue;

		if ((pAddrTable->table[i].dwAddr & 0x000000FF) == 127)
			continue;

		if ((pAddrTable->table[i].dwAddr & 0x000000FF) == 10)
			continue;

		if (
			((pAddrTable->table[i].dwAddr & 0x000000FF) == 172)
			&& (((pAddrTable->table[i].dwAddr & 0x0000FF00) >> 8) >= 16)
			&& (((pAddrTable->table[i].dwAddr & 0x0000FF00) >> 8) <= 31)
		)
			continue;

		if (
			((pAddrTable->table[i].dwAddr & 0x000000FF) == 192)
			&& (((pAddrTable->table[i].dwAddr & 0x0000FF00) >> 8) == 168)
		)
			continue;

		if (
			((pAddrTable->table[i].dwAddr & 0x000000FF) == 169)
			&& (((pAddrTable->table[i].dwAddr & 0x0000FF00) >> 8) == 254)
		)
			continue;

		std::ostringstream oss;
		oss << ((pAddrTable->table[i].dwAddr) & 0x000000FF);
		oss << ".";
		oss << (((pAddrTable->table[i].dwAddr) & 0x0000FF00) >> 8);
		oss << ".";
		oss << (((pAddrTable->table[i].dwAddr) & 0x00FF0000) >> 16);
		oss << ".";
		oss << (((pAddrTable->table[i].dwAddr) & 0xFF000000) >> 24);

		HGLOBAL pClipText = GlobalAlloc(GMEM_MOVEABLE, oss.str().length() + 1);

		if (pClipText)
		{
			char* pszClipText = static_cast<char*>(GlobalLock(pClipText));
			if (pszClipText)
			{
				oss.str().copy(pszClipText, oss.str().length());
				pszClipText[oss.str().length()] = 0;
				GlobalUnlock(pClipText);

				if (OpenClipboard(NULL))
				{
					EmptyClipboard();
					if (NULL == SetClipboardData(CF_TEXT, pClipText))
						GlobalFree(pClipText);
					CloseClipboard();
				}
			}
		}

		break;
	}

	GlobalFree(pAddrTable);
	return 0;
}
